/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http:www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http:www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.common.util;

import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.Random;
import java.util.UUID;
import org.apache.commons.codec.binary.Base64;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * {@link CipherUtil}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public final class CipherUtil {

    private static final Logger logger = LoggerFactory.getLogger(CipherUtil.class);

    /**
     * Get the SHA hash from the specified password.
     *
     * @param password The password to hash
     * @param salt The salt to use
     * @return The SHA hashed password
     */
    public static String getSHA(String password, String salt) {
        try {
            if (password == null || salt == null) return null;
            MessageDigest md = MessageDigest.getInstance("SHA-256");
            md.update(salt.getBytes("UTF-8"));
            byte[] hashbytes = md.digest(password.getBytes("UTF-8"));

            return Base64.encodeBase64String(hashbytes);
        } catch (Exception ex) {
            //TODO: throw exception?
            logger.error("Failure creating SHA digest", ex);
            return "";
        }
    }

    /**
     * Get the MD5 hash from a string
     * @param data The string to get the has for
     * @return The MD5 hash of data
     * @throws NoSuchAlgorithmException
     * @throws UnsupportedEncodingException
     */
    public static String getMD5(String data) throws NoSuchAlgorithmException, UnsupportedEncodingException {
        StringBuffer ret = new StringBuffer();
        MessageDigest md = MessageDigest.getInstance("MD5");
        byte[] hashbytes = md.digest(data.getBytes("UTF-8"));

        for (int i = 0; i < hashbytes.length; i++) {
            if ((0xff & hashbytes[i]) < 0x10) {
                ret.append("0" + Integer.toHexString((0xFF & hashbytes[i])));
            } else {
                ret.append(Integer.toHexString(0xFF & hashbytes[i]));
            }
        }
        return ret.toString();
    }

    /**
     * Generate a random UUID and return it as a string
     *
     * @return A random UUID as string
     */
    public static String getUUID() {
        UUID uid = java.util.UUID.randomUUID();
        return uid.toString();
    }

    /**
     * Function to generate random salt
     *
     * @return string of random salt
     */
    public static String generateSalt() {
        Random random = new SecureRandom();
        byte[] salt = new byte[20];
        random.nextBytes(salt);

        return Base64.encodeBase64String(salt);
    }
}
