/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.keymanagement.commons;

import java.security.Key;
import com.openexchange.guard.common.java.Strings;

/**
 * {@link GuardMasterKey}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public final class GuardMasterKey {

    private final String mc;
    private final String rc;
    private final String publicKey;
    private final Key privateKey;

    /**
     * Initialises a new {@link GuardMasterKey}.
     */
    public GuardMasterKey(String mc, String rc, String publicKey, Key privateKey) {
        super();
        if (Strings.isEmpty(mc)) {
            throw new IllegalArgumentException("The 'MC' value of the OX Guard master key can be neither 'null' nor empty");
        }
        if (Strings.isEmpty(rc)) {
            throw new IllegalArgumentException("The 'RC' value of the OX Guard master key can be neither 'null' nor empty");
        }

        if (Strings.isEmpty(publicKey)) {
            throw new IllegalArgumentException("The 'publicKey' value of the OX Guard master key can be neither 'null' nor empty");
        }
        if (privateKey == null) {
            throw new IllegalArgumentException("The 'privateKey' of the OX Guard master key can be neither 'null' nor empty");
        }

        this.mc = mc;
        this.rc = rc;
        this.publicKey = publicKey;
        this.privateKey = privateKey;
    }

    /**
     * Gets the MC
     *
     * @return The mc
     */
    public String getMC() {
        return mc;
    }

    /**
     * Gets the RC
     *
     * @return The rc
     */
    public String getRC() {
        return rc;
    }

    /**
     * Gets the publicKey
     *
     * @return The publicKey
     */
    public String getPublicKey() {
        return publicKey;
    }

    /**
     * Gets the privateKey
     *
     * @return The privateKey
     */
    public Key getPrivateKey() {
        return privateKey;
    }
}
