/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard;

import com.google.gson.JsonObject;
import com.openexchange.exception.OXException;

/**
 * {@link GuardMaintenanceService}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public interface GuardMaintenanceService {

    /**
     * Tests the specified email against the MailResolver
     *
     * @param mail The e-mail address to test with
     * @return The response from the server
     * @throws OXException
     */
    JsonObject test(String mail) throws OXException;

    /**
     * Resets the specified e-mail and sends a new password to the user
     *
     * @param mail The e-mail address of the user for whom to reset the password
     * @throws OXException
     */
    void reset(String mail) throws OXException;

    /**
     * Removes the PIN for the specified guest user
     *
     * @param mail The e-mail address of the guest user for whom the PIN shall be removed
     * @throws OXException
     */
    void removePIN(String mail) throws OXException;

    /**
     * Upgrades a guest account to an OX account
     *
     * @param mail The e-mail address of the guest user that will get upgraded
     * @throws OXException
     */
    void upgrade(String mail) throws OXException;

    /**
     * Delete a user by email address
     * @param email
     * @throws OXException
     */
	void delete(String email) throws OXException;

	/**
	 * Reset Guest account, create new keys
	 * @param email
	 * @param force
	 * @throws OXException
	 */
	void resetGuest(String email, boolean force) throws OXException;

    /**
     * Changes a user's email, context or id, indentified by email address
     * @param email
     * @param newEmail
     * @param newContext
     * @param newUserId
     */
    void changeUser (String email, String newEmail) throws OXException;

}
